Module sched

Structs

ParameterizedScheduler
Pid
Wrapper around pid_t.
SchedulerParams
Schedule parameters for a thread. Priority is the only supported parameter by the kernel at the moment. This is a wrapper around libc::sched_param

Enums

PreemptRtError
PreemptRt error type. When libc functions return -1, errno will be fetched via libc.
Scheduler
The type of scheduler for use with sched_getscheduler and sched_setscheduler. See man_sched(7) for more details on the differences in behavior.

Traits

IntoSchedParams

Functions

get_scheduler
Get the current scheduler in use for a given process or thread. Using Pid::from_raw(0) will fetch the scheduler for the calling thread.
get_scheduler_params
Get the schedule parameters (currently only priority) for a given thread. Using Pid::from_raw(0) will return the parameters for the calling thread.
set_scheduler
Set the scheduler and parameters for a given process or thread. Using Pid::from_raw(0) will set the scheduler for the calling thread.
set_scheduler_params
Set the schedule parameters (currently only priority) for a given thread. Using Pid::from_raw(0) will return the parameters for the calling thread.

Type Aliases

RtResult
PreemptRt result type